# Generated by roxygen2: do not edit by hand

export(dr_app)
export(dr_body)
export(dr_delete)
export(dr_delete_cpp)
export(dr_file)
export(dr_get)
export(dr_get_cpp)
export(dr_get_cpp_stream)
export(dr_header)
export(dr_html)
export(dr_json)
export(dr_on_error)
export(dr_post)
export(dr_post_cpp)
export(dr_post_cpp_stream)
export(dr_put)
export(dr_put_cpp)
export(dr_query)
export(dr_rate_limit)
export(dr_redirect)
export(dr_response)
export(dr_running)
export(dr_serve)
export(dr_static)
export(dr_status)
export(dr_stop)
export(dr_stream)
export(dr_stream_sse)
export(dr_text)
export(dr_use)
export(dr_ws)
export(dr_ws_broadcast)
export(dr_ws_client_close)
export(dr_ws_client_send)
export(dr_ws_close)
export(dr_ws_connect)
export(dr_ws_cpp)
export(dr_ws_join)
export(dr_ws_leave)
export(dr_ws_send)
export(dr_ws_shutdown)
export(pr_run)
importFrom(later,current_loop)
useDynLib(drogonR, .registration = TRUE)
